componenttools.iterate_timeline_backward_in_expr
================================================

.. autofunction:: abjad.tools.componenttools.iterate_timeline_backward_in_expr.iterate_timeline_backward_in_expr
